**************************************
/*REPLICATION DATASET FOR RFS SUBMISSION "An inquiry ..."
Author: LH
Date: Oct 3, 2020
Input1: RFSregion_oct2020.dta"
Input2: RFScountry_oct2020.dta"
Supporting input: 	RAI v.3 and ROKKAN v.2 

/*this do file accompanies the replication dataset for the article "Language Difference and Regional Authority,"
which will be published in the Anniversary issue of Regional and Federal Studies
authors: Sarah Shair-Rosenfield, Arjan H. Schakel, Sara Niedzwiecki, Gary Marks, Liesbet Hooghe, Sandra Chapman-Osterkatz
for questions, please contact hooghe@unc.edu
*/

***************************************/
INTRODUCTION
***************************************/
use year, countryname, countryid, countryabbr, regionid, regionname
gen MLG=1 if tier_RAI!=. 
replace MLG=0 if tier_RAI==. // this distinguishes countries that are treated as regions (MLG=0) from regions 

* WORLDREGION (own coding)
gen worldregion=1 if (countryid>50 & countryid<100) | countryid>149| countryid==21
replace worldregion=2 if countryid>99 & countryid<150
replace worldregion=3 if countryid==7| countryid==42| countryid==28| countryid==43| countryid==2
replace worldregion=4 if worldregion==.
tab countryid worldregion
tab countryid worldregion
label define worldregion 1 "Asia" 2 "Latin America" 3 "New World" 4 "Eurasia"
label values worldregion worldregion
label variable worldregion "four regions"

order year worldregion countryname countryid countryabbr regionid regionname MLG missing

**************************************
DEPENDENT VARIABLES: regional authority
**************************************
tier_selfrule, tier_sharedrule, tier_RAI // RAI (or component) for this region -- source: RAI v.3

RAI_difference // difference in RAI between this region and a standard region

/*calculated as:*/
gen RAI_standard=.
replace RAI_standard==tier_RAI // 
gsort countryid -standard_region
edit countryname countryid regionname autonomy asymmetry dependency tier_RAI RAI_standard 
replace replace RAI_standard=. if countryid==5 // etc. for every country that has non-standard regions replace value [Belgium and BIH have no standard regions]
gen RAI_difference= tier_RAI-RAI_standard 
replace RAI_difference=tier_RAI if RAI_difference==.

*************************
ROKKAN PROPERTIES
*************************

* (a) ISLAND OR NOT (own coding)
use islandregion from "Rokkan dataset may10.xlsx"
label variable islandregion "island region"

*(b) TRAVEL DISTANCE
use travel1, travel2, travel1log from "distance dataset april 21 2020.xlsx"
gen travel1log=log10(travel1)
label variable travel1log "distance in km from capital as-crow-flies --log10"
label variable travel2 "travel time by car"

* (c) LANGUAGE REGION
use language1, language2
label variable language1 "at least half of pop speaks different language from core"
label variable language2 "majority for one non-core language" 

* (d) FORMER STATE CORE
use statehood
label variable statehood "former state core"

* (e) FORMER UNI-LEVEL GOVERNANCE
use unilevel, multilevel 
label variable unilevel "unilevel governance pre-colonization"
label variable multilevel "multilevel governance pre-colonization"

order islandregion travel1 travel1log travel2 language1 language2 statehood unilevel multilevel, after (ROKKAN)

*********************
STATUS_REGION
*********************
use type, autonomy, asymmetry, dependency, capitalisregion, capital, standard_region, indigenous, metro
/*source: data from RAI v.3*/

***************************
OTHER VARIABLES
***************************

* (f) EUROSETTLERS (ACEMOGLU ET AL.)
use euro1900n2, euro1900n // [euro1900n has missing values as in AJR]  
label variable euro1900n2 "European settlers % in 1900, AJR -- revised"

* (g) LINGUISTIC FRACTIONALIZATION (ALESINA ET AL.)
use cf //some missing values with own complements
label variable cf "linguistic fractionalization  (Alesina data)"

* (i) democracy
use democracy (Vdem), polity2018 (robustness)
egen democracy=rowmean( VDliberal2018 VDelect2018)
label variable democracy "VDem average liberal and elect"

* (j) other controls
use GDPpco, GDPlog  // log10 of GDPpco from Penn world tables ed. 7.1
popregion, arearegion, popregionlog, arearegionlog  // log10 data at regional level from Penn world, statoid and wikipedia, own calculations
pop1000, area1000, poplog, arealog // log10 data at country level, own calculations
polity2018 // control for democracy
federal1950, federal2018 // is region in a country that is a formal federation (own)
colonyn // 1= was region part of a formerly (European-)colonized country? this includes Israel, HK, and Macao [Becker data)
colempire // (most recent) colonial empire 1 = britain, 2 = france, 3 = dutch, 4 = portuguese, 5 = spain 

order OTHERVARIABLES euro1900n2 euro1900n cf democracy VDliberal2018 VDelect2018 GDPpco GDPlog popregion arearegion popregionlog arearegionlog pop1000 area1000 poplog arealog federal1950 federal2018 polity2018 colonyn colempire, after (multilevel)

**********************************
/*FIGURE 1,2,3,4: ART: 
1: barriers to interaction & language difference; 
2: casues and consequences of language difference; 
3: governance, settlers, language difference; 
4: expected marginal effect of a distinct language*/
**********************************

**********************************
*FIGURE 5: regional authority in 2018 
**********************************
histogram tier_RAI if MLG==1 & regionid!=12402 & regionid!=4111, frequency fcolor(bluishgray) lcolor(dknavy) lwidth(thin) normal normopts(lcolor(black) lwidth(medthin) lpattern(solid)) kdensity kdenopts(lcolor(black) lwidth(medthin) lpattern(dash) gaussian) ylabel(0(20)260) xlabel(0(5)30) xmtick(##5)
/*12402=counties in trinidad; 4111= abolished regions in England*/

*************************************
*TABLE 1: EXPLAINING A LANGUAGE REGION
**************************************
logit language1 islandregion travel1log statehood i.unilevel##c.euro1900n2 cf if regionid!=12402 & regionid!=4111, vce (cl countryid) or  // model 1
fitstat

/*note: regionid!=12402 & regionid!=4111 -- this excludes counties in Trinidad that do not meet criterion, and abolished regions in England*/

tab islandregion language1 if regionid!=12402 & regionid!=4111
tab statehood language1 if statehood==1 & countryid==150
list countryname regionname statehood language1 if statehood==1

************************************************************************
*FIGURE 6: How colonial settlement interacts with multi-level governance
************************************************************************
logit language1 islandregion travel1log statehood i.unilevel##c.euro1900n2 cf if regionid!=12402 & regionid!=4111, vce (cl countryid) or  // model 2
margins, at (euro1900n2=(0 (10) 100) unilevel=(0 1)) l(90) atmeans
marginsplot // Figure 6

                ******************robustness in appendix****************
/*descriptives table A.1 and table A.2 */
tabstat language1 statehood unilevel islandregion travel1 travel1log euro1900n2 cf if regionid!=12402 & regionid!=4111, stats (mean p50 min max sd N)
corr language1 statehood unilevel islandregion travel1 travel1log euro1900n2 cf if regionid!=12402 & regionid!=4111
				
/*Table A.3. explaining the likelihood of a language region*/
logit language1 islandregion travel1log statehood i.unilevel##c.euro1900n2 cf if regionid!=12402 & regionid!=4111, vce (cl countryid) or  // model 1
margins, at (euro1900n2=(0 (10) 100) multilevel=(0 1)) l(90)
marginsplot
estat classification
estat gof
fitstat
lroc
estat gof, group (5) table  // Hosmer-Lemeshow -- further diagnostics

jackknife: logit language1 islandregion travel1log statehood i.unilevel##c.euro1900n2 cf if regionid!=12402 & regionid!=4111, vce (cl countryid) or // model 2 -- jackknife
logit language1 islandregion travel1log statehood i.unilevel##c.euro1900n2 ib4.worldregion cf if regionid!=12402 & regionid!=4111, vce (cl countryid) or // model 3 -- controlling for worldregions
logit language1 islandregion travel1log statehood i.unilevel##c.euro1900n2 cf if MLG==1 & regionid!=12402 & regionid!=4111, vce (cl countryid) or  // model 4 --- excluding states without regions
logit language1 islandregion travel1log statehood i.unilevel##c.euro1900n2 cf if colonyn==1 & regionid!=12402 & regionid!=4111, vce (cl countryid) or  // model 5 --- ex-colonies
logit language1 islandregion travel1log statehood i.unilevel##c.euro1900n2 cf i.colempire if colonyn==1 & regionid!=12402 & regionid!=4111 , vce (cl countryid) or  // model 6 -- ex-colonies and empire
logit language2 islandregion travel1log statehood i.unilevel##c.euro1900n2 cf if regionid!=12402 & regionid!=4111, vce (cl countryid) or  // model 7 -- restrictive definition of language region

***************************************
*TABLE 2: Language regions and regional authority
***************************************
*focus on regions that exist in a regional-tier framework only
list countryname regionname regionid indigenous tier_RAI RAI_standard if indigenous==1
gen noframe=1 if regionid==706| regionid==707| regionid==4205| regionid==8910| regionid==8911| regionid==10403| regionid==10704| regionid==10802| regionid==15202 
replace noframe=0 if noframe==.
tab noframe
gen missing=1 if democracy==.| GDPpco==.| tier_RAI==.| language1==.| noframe==1  // this is to keep cases constant across models
replace missing=0 if missing==.

reg tier_RAI language1 democracy statehood popregionlog arearegionlog GDPlog10 cf if missing==0, vce (cl countryid) // model 1 Table 2
reg tier_RAI i.language1##c.democracy statehood popregionlog arearegionlog GDPlog10 cf if missing==0, vce (cl countryid) // model 2 Table 2


                ******************robustness in appendix****************
/*descriptives Table A.4 and A.5*/
tabstat tier_RAI RAI_difference language1 statehood popregion popregionlog arearegion arearegionlog democracy GDPpco GDPlog10 cf if missing==0, stats (mean p50 min max sd N)
tabstat tier_RAI RAI_difference language1 statehood popregion popregionlog arearegion arearegionlog democracy GDPpco GDPlog10 cf if missing==0 & countryid!=4 & countryid!=5, stats (mean p50 min max sd N)
corr tier_RAI RAI_difference language1 statehood popregionlog arearegionlog democracy GDPlog10 cf if missing==0


	***************************Table A.6: robustness in appendix: explaining regional authority (complement to table 2 in paper)*/
reg tier_RAI i.language1##c.democracy statehood popregionlog arearegionlog GDPlog10 cf if missing==0, vce (cl countryid) // model 2 baseline
jackknife: reg tier_RAI i.language1##c.democracy statehood popregionlog arearegionlog GDPlog10 cf if missing==0, cl (countryid) // model 3  jackknife
reg tier_RAI i.language1##c.democracy statehood popregionlog arearegionlog GDPlog10 cf ib4.worldregion if missing==0, vce (cl countryid) // model 4 worldregion
reg tier_RAI i.language1##c.polity2018 statehood popregionlog arearegionlog GDPlog10 cf if missing==0, vce (cl countryid) // model 5 alternative democracy
reg tier_RAI i.language2##c.democracy statehood popregionlog arearegionlog GDPlog10 cf if missing==0, vce (cl countryid) // model 6 restrictive language region
reg tier_selfrule i.language1##c.democracy statehood popregionlog arearegionlog GDPlog10 cf if missing==0, vce (cl countryid) // model 7 selfrule as DV


**************************************************************
*FIGURE 7: How language makes a difference for a region’s authority
*Table A.7 in Appendix: The effect of language on a region's authority
**************************************************************
gen RAI_difference= tier_RAI-RAI_standard 
replace RAI_difference=tier_RAI if RAI_difference==.

//*how to deal with Belgium and BIH, which do not have standard tier but have powerful asymmetrical regions**//
/* MOST CONSERVATIVE: exclude // Figure 7
exclude Belgium (4) and Bosnia-Herzegovina because no standard regions -- PS. result is sign if B, BIS are included at full RAI, if estimated standard RAI imposed*/
reg RAI_difference i.language1##c.democracy statehood popregionlog arearegionlog GDPlog10 cf if missing==0 & countryid!=4 & countryid!=5 // model 1 appendix
margins, dydx(language1) at (democracy=(.05 (.05) .9)) l(90)
marginsplot, saving (demlangdifferenceb.gph) // Figure 7

/*ALTERNATIVES: ESTIMATE STANDARD TIER VALUE*/
/*(A) estimate of theoretical tier (Federacie for BIH=26 || French community for Belgium = 21.5)
gen RAI_difference1=RAI_difference //then create RAI_standard for Belgian regions=21.5 & RAI_standard for BIH=26, and calculate B and BIZ RAI_difference*/
reg RAI_difference1 i.language1##c.democracy statehood popregionlog arearegionlog GDPlog10 cf if missing==0  // model 2 appendix
/*(B) estimate upper-tier score on basis of prior upper tier (provinces in Belgium pre-fed (16); cantons in BIH (23.5)*/
reg RAI_difference2 i.language1##c.democracy statehood popregionlog arearegionlog GDPlog10 cf if missing==0 

histogram democracy if language1==1 & missing==0, bin (30) frequency saving (demlanghisto.gph, replace) // use this to create Fig A.11 in appendix


***************************************************************
*FIGURE 8: The effect of language difference for regional authority in a country conditional on democracy
Table 4 appendix: The Effect of language regions on the authority of a regional tier
**************************************************************************
use "RFScountry_oct2020.dta"

gen DEPENDENTVAR=.
order DEPENDENTVAR RAIpropn RAIpopn, after (MLG)

gen INDEPVAR=.
order INDEPVAR languagepropn3 democracy  statehoodpropn3 poplog arealog GDPlog10 cf languagepopn statehoodpopn3, after (RAIpopn)

gen OTHERVAR=.
order OTHERVAR, after (statehoodpopn3)

reg RAIpropn languagepropn3 democracy  statehoodpropn3 poplog arealog GDPlog10 cf 
reg RAIpropn c.languagepropn3##c.democracy statehoodpropn3 poplog arealog GDPlog10 cf // model 1  
margins, at (languagepropn3=(0 (.1) 1) democracy=(.2 .8) ) l(90) atmeans   // use this FOR FIGURE 8
marginsplot, saving (langdemcountry.gph, replace)

margins, at (languagepropn3=(0 (.33) 1) democracy=(.2 .8) ) l(90) atmeans   // use this for one-third language regions

reg RAIpopn c.languagepopn3##c.democracy statehoodpopn3 poplog arealog GDPlog10 cf // model 2  --- use this as alternative



********appendix descriptives on Table A.8 and A.9*************
tabstat RAIpropn RAIpopn languagepropn3 languagepopn3 statehoodpropn3 statehoodpopn3 poplog arealog democracy  GDPlog10 cf if RAIpopn!=. & democracy!=. & GDPlog10!=., stats (mean p50 min max sd N) 

corr RAIpropn RAIpopn languagepropn3 languagepopn3 statehoodpropn3 statehoodpopn3 poplog arealog democracy  GDPlog10 cf if MLG==1 & democracy!=. & GDPlog10!=.

****************Table A.10: Democracy, language regions, and their country-wide effect
reg RAIpropn c.languagepropn3##c.democracy statehoodpropn3 poplog arealog GDPlog10 cf // model 1  
reg RAIpopn c.languagepopn3##c.democracy statehoodpopn3 poplog arealog GDPlog10 cf // model 2  --- 
fitstat

***********************
*FIGURE A.11 ABOUT DISTRIBUTION OF LANGUAGE REGIONS FOR APPENDIX*
********************************
use "RFScountry_oct2020.dta"
histogram languagepropn3 if MLG==1, bin(30) frequency normal saving (langpropnhisto.gph, replace)
graph combine "langdemcountry" "langpropnhisto" 
use "RFSregion_oct2020.dta"
histogram democracy if language1==1 & missing==0, bin (20) frequency saving (demlanghisto.gph, replace)
graph combine "demlanghisto" "langpropnhisto" // Figure Appendix A.11

*************************************************
*Table A.12 REGIONS BY COUNTRY 
*****************************************************
use "RFSregion_oct2020.dta"
tabstat count2 language1 statehood multilevel islandregion travel1 travel1log popregion arearegion euro1900n2 cf democracy GDPpc, stats (p50 sum N) by (countryname)
tabstat language1 statehood multilevel islandregion, stats (sum) by (countryname)
tabstat travel1 popregion arearegion euro1900n2 cf democracy GDPpco, stats (p50) by (countryname)
tabstat travel1 if countryid==91, stats (max)
